import { createIconBase } from '../createIcon.js';

export const DotCircleIconConfig = {
  name: 'DotCircleIcon',
  icon: {"xOffset":0,"yOffset":0,"width":512,"height":512,"svgPathData":"M256 8C119.033 8 8 119.033 8 256s111.033 248 248 248 248-111.033 248-248S392.967 8 256 8zm80 248c0 44.112-35.888 80-80 80s-80-35.888-80-80 35.888-80 80-80 80 35.888 80 80z"},
  rhUiIcon: null,
};

export const DotCircleIcon = createIconBase(DotCircleIconConfig);

export default DotCircleIcon;