import { createIconBase } from '../createIcon.js';

export const RhStandardHarveyBall80IconConfig = {
  name: 'RhStandardHarveyBall80Icon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M18 3.375A14.625 14.625 0 1 0 32.625 18 14.642 14.642 0 0 0 18 3.375Zm-.625 1.282v12.479L5.491 13.308a13.378 13.378 0 0 1 11.884-8.651Z"},
  rhUiIcon: null,
};

export const RhStandardHarveyBall80Icon = createIconBase(RhStandardHarveyBall80IconConfig);

export default RhStandardHarveyBall80Icon;